@@ -37,6 +37,7 @@ impl PEMKey {
 pub struct AccountSettings {
     pub webhook: Option<AccountWebhookSettings>,
     pub google: Option<AccountGoogleIntegration>,
+    pub outlook: Option<AccountOutlookIntegration>,
 }
 
 #[derive(Debug, Clone, Serialize, Deserialize)]
@@ -82,12 +83,19 @@ pub struct AccountGoogleIntegration {
     pub client_secret: String,
     pub redirect_uri: String,
 }
+#[derive(Debug, Serialize, Deserialize, Clone)]
+pub struct AccountOutlookIntegration {
+    pub client_id: String,
+    pub client_secret: String,
+    pub redirect_uri: String,
+}
 
 impl Default for AccountSettings {
     fn default() -> Self {
         Self {
             webhook: None,
             google: None,
+            outlook: None,
         }
     }
 }
