@@ -14,7 +14,8 @@ mod timespan;
 mod user;
 
 pub use account::{
-    Account, AccountGoogleIntegration, AccountSettings, AccountWebhookSettings, PEMKey,
+    Account, AccountGoogleIntegration, AccountOutlookIntegration, AccountSettings,
+    AccountWebhookSettings, PEMKey,
 };
 pub use calendar::{Calendar, CalendarSettings, SyncedCalendar};
 pub use date::format_date;
@@ -34,4 +35,6 @@ pub use shared::entity::{Entity, ID};
 pub use shared::metadata::{Meta, Metadata};
 pub use shared::recurrence::{RRuleFrequency, RRuleOptions};
 pub use timespan::TimeSpan;
-pub use user::{User, UserGoogleIntegrationData, UserIntegrationProvider};
+pub use user::{
+    User, UserGoogleIntegrationData, UserIntegrationProvider, UserOutlookIntegrationData,
+};
