@@ -42,6 +42,7 @@ impl Meta<ID> for User {
 #[serde(tag = "provider")]
 pub enum UserIntegrationProvider {
     Google(UserGoogleIntegrationData),
+    Outlook(UserOutlookIntegrationData),
 }
 
 #[derive(Debug, Clone, Serialize, Deserialize)]
@@ -50,3 +51,10 @@ pub struct UserGoogleIntegrationData {
     pub access_token: String,
     pub access_token_expires_ts: i64,
 }
+
+#[derive(Debug, Clone, Serialize, Deserialize)]
+pub struct UserOutlookIntegrationData {
+    pub refresh_token: String,
+    pub access_token: String,
+    pub access_token_expires_ts: i64,
+}
